pub struct OpenBundledPositionInstructionArgs {
pub bundle_index: u16,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
}Fields
bundle_index: u16tick_lower_index: i32tick_upper_index: i32Trait Implementations
Sourceimpl BorshDeserialize for OpenBundledPositionInstructionArgs
impl BorshDeserialize for OpenBundledPositionInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OpenBundledPositionInstructionArgs
impl Clone for OpenBundledPositionInstructionArgs
Sourcefn clone(&self) -> OpenBundledPositionInstructionArgs
fn clone(&self) -> OpenBundledPositionInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for OpenBundledPositionInstructionArgs
impl PartialEq for OpenBundledPositionInstructionArgs
Sourcefn eq(&self, other: &OpenBundledPositionInstructionArgs) -> bool
fn eq(&self, other: &OpenBundledPositionInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for OpenBundledPositionInstructionArgs
impl StructuralPartialEq for OpenBundledPositionInstructionArgs