pub struct OpenPositionWithTokenExtensionsCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for OpenPositionWithTokenExtensions via CPI.
Accounts:
[writable, signer]funder[]owner[writable]position[writable, signer]position_mint[writable]position_token_account[]whirlpool[]token2022_program[]system_program[]associated_token_program[]metadata_update_auth
Implementations
Sourceimpl<'a, 'b> OpenPositionWithTokenExtensionsCpiBuilder<'a, 'b>
impl<'a, 'b> OpenPositionWithTokenExtensionsCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn funder(&mut self, funder: &'b AccountInfo<'a>) -> &mut Self
pub fn owner(&mut self, owner: &'b AccountInfo<'a>) -> &mut Self
pub fn position(&mut self, position: &'b AccountInfo<'a>) -> &mut Self
pub fn position_mint(&mut self, position_mint: &'b AccountInfo<'a>) -> &mut Self
pub fn position_token_account( &mut self, position_token_account: &'b AccountInfo<'a>, ) -> &mut Self
pub fn whirlpool(&mut self, whirlpool: &'b AccountInfo<'a>) -> &mut Self
pub fn token2022_program( &mut self, token2022_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn associated_token_program( &mut self, associated_token_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn metadata_update_auth( &mut self, metadata_update_auth: &'b AccountInfo<'a>, ) -> &mut Self
pub fn tick_lower_index(&mut self, tick_lower_index: i32) -> &mut Self
pub fn tick_upper_index(&mut self, tick_upper_index: i32) -> &mut Self
pub fn with_token_metadata_extension( &mut self, with_token_metadata_extension: bool, ) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult