pub struct RemainingAccountsInfo {
pub slices: Vec<RemainingAccountsSlice>,
}Fields
slices: Vec<RemainingAccountsSlice>Trait Implementations
Sourceimpl BorshDeserialize for RemainingAccountsInfo
impl BorshDeserialize for RemainingAccountsInfo
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RemainingAccountsInfo
impl Clone for RemainingAccountsInfo
Sourcefn clone(&self) -> RemainingAccountsInfo
fn clone(&self) -> RemainingAccountsInfo
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemainingAccountsInfo
impl Debug for RemainingAccountsInfo
Sourceimpl PartialEq for RemainingAccountsInfo
impl PartialEq for RemainingAccountsInfo
impl Eq for RemainingAccountsInfo
impl StructuralPartialEq for RemainingAccountsInfo